==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/lib/puppet/type/wls_jms_queue.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/weblogic/core'

# docs
# rubocop: disable Metrics/ModuleLength
module Puppet
  # rubocop: disable Metrics/BlockLength
  Type.newtype(:wls_jms_queue) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a Queue in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_queue { 'jmsClusterModule:ErrorQueue':
          ensure            => 'present',
          defaulttargeting  => '0',
          distributed       => '1',
          expirationpolicy  => 'Discard',
          jndiname          => 'jms/ErrorQueue',
          redeliverydelay   => '-1',
          redeliverylimit   => '-1',
          subdeployment     => 'jmsServers',
          timetodeliver     => '-1',
          timetolive        => '-1',
          templatename      => 'Template',
          messagelogging    => '1',
          consumptionpaused => '0',
          insertionpaused   => '0',
          productionpaused  => '0',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/%{object_type}')

    validate do
      return if purging
      return if self[:ensure] == :absent # No checking when we are absenting
      fail "#{path}: Defaulttargeting and Subdeployment are both set, only one can be active for JMS components" if defaulttargeting == :"1" && subdeployment
      fail "#{path}: Either defaulttargeting or a subdeployment needs to be selected for JMS components" if defaulttargeting == :"0" && !subdeployment
    end

    on_create do
      Puppet.info "create #{name} "
      actual_type = distributed_to_path.chop
      actual_path = bean_path.subst(to_hash)
      fail "#{path}: Parent resource #{actual_path} doesn't exists." unless wls_config.exists?(actual_path)
      wls_config.create(actual_type, actual_path, self[key_name])
      nil
    end

    on_destroy do |_|
      if exists_distributed?
        wls_config.destroy('UniformDistributedQueue', bean_path.subst(as_distributed), self[key_name])
      elsif exists_non_distributed?
        wls_config.destroy('Queue', bean_path.subst(as_non_distributed), self[key_name])
      else
        fail "#{path}: queue doesn't exist."
      end
      nil
    end

    #
    # Because bean_path uses the variable object_path, we need to have it available all the time
    # This code adds it to the hash based on the setting of distributed.
    #
    def to_hash
      hash = super
      hash[:object_type] = distributed_to_path
      hash
    end

    def as_distributed
      to_hash.dup.merge(:object_type => 'UniformDistributedQueues')
    end

    def as_non_distributed
      to_hash.dup.merge(:object_type => 'Queues')
    end

    def exists_distributed?
      wls_config.exists?("#{bean_path.subst(as_distributed)}/#{self[key_name]}")
    end

    def exists_non_distributed?
      wls_config.exists?("#{bean_path.subst(as_non_distributed)}/#{self[key_name]}")
    end

    #
    # Only use elements on the path where this condition is true. The condition is
    # that is has specified serverTemplates
    #
    index_condition do |_name, path, _wls_config|
      %w[Queues UniformDistributedQueues].include?(path.split('/').last)
    end

    ensurable
    parameter :queue_name
    parameter :errordestinationtype
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :distributed
    property :jndiname
    property :subdeployment
    property :balancingpolicy
    property :quota
    property :defaulttargeting
    property :errordestination
    property :expirationloggingpolicy
    property :redeliverylimit
    property :expirationpolicy
    property :redeliverydelay
    property :timetodeliver
    property :deliverymode
    property :timetolive
    property :forwarddelay
    property :templatename
    property :messagelogging
    property :destination_keys
    property :insertionpaused
    property :consumptionpaused
    property :productionpaused
    extraproperties do
      property :override_delivery_mode
      property :override_priority
      property :override_redelivery_delay
      property :override_template_bean
      property :override_time_to_deliver
      property :override_time_to_live
      property :thresholds_bytes_high
      property :thresholds_bytes_low
      property :thresholds_messages_high
      property :thresholds_messages_low
      property :thresholds_template_bean
      property :attach_sender
      property :delivery_expiration_logging_policy
      property :delivery_expiration_policy
      property :delivery_redelivery_limit
      property :delivery_template_bean
      property :incomplete_work_expiration_time
      property :insertion_paused_at_startup
      property :jms_create_destination_identifier
      property :jndi_name
      property :local_jndi_name
      property :log_message_logging_enabled
      property :log_message_logging_format
      property :log_template_bean
      property :maximum_message_size
      property :production_paused_at_startup
      property :reset_delivery_count_on_forward
      property :saf_export_policy
      property :consumption_paused_at_startup
      property :default_targeting_enabled
      property :default_unit_of_order
      property :load_balancing_policy
      property :messaging_performance_preference
      property :notes
      property :sub_deployment_name
      property :template
      property :unit_of_order_routing
      property :unit_of_work_handling_policy
      property :forward_delay
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :queue_name) do
      /(.+):(.+)/
    end

    def distributed_to_path
      case distributed
      when 0, '0' then 'Queues'
      when 1, '1' then 'UniformDistributedQueues'
      else
        fail "#{path}: Invalid value for distributed"
      end
    end
  end
end

==> enterprisemodules-wls_config-3.2.3.tar.gz: enterprisemodules-wls_config-3.2.3/lib/puppet/type/wls_jms_queue.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/weblogic/core'

# docs
# rubocop: disable Metrics/ModuleLength
module Puppet
  # rubocop: disable Metrics/BlockLength
  Type.newtype(:wls_jms_queue) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a Queue in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_queue { 'jmsClusterModule:ErrorQueue':
          ensure            => 'present',
          defaulttargeting  => '0',
          distributed       => 1,
          expirationpolicy  => 'Discard',
          jndiname          => 'jms/ErrorQueue',
          redeliverydelay   => '-1',
          redeliverylimit   => '-1',
          subdeployment     => 'jmsServers',
          timetodeliver     => '-1',
          timetolive        => '-1',
          templatename      => 'Template',
          messagelogging    => 1,
          consumptionpaused => '0',
          insertionpaused   => '0',
          productionpaused  => '0',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/%{object_type}')

    validate do
      return if purging
      return if self[:ensure] == :absent # No checking when we are absenting
      fail "#{path}: Defaulttargeting and Subdeployment are both set, only one can be active for JMS components" if defaulttargeting == :"1" && subdeployment
      fail "#{path}: Either defaulttargeting or a subdeployment needs to be selected for JMS components" if defaulttargeting == :"0" && !subdeployment
    end

    on_create do
      Puppet.info "create #{name} "
      actual_type = distributed_to_path.chop
      actual_path = bean_path.subst(to_hash)
      fail "#{path}: Parent resource #{actual_path} doesn't exists." unless wls_config.exists?(actual_path)
      wls_config.create(actual_type, actual_path, self[key_name])
      nil
    end

    on_destroy do |_|
      if exists_distributed?
        wls_config.destroy('UniformDistributedQueue', bean_path.subst(as_distributed), self[key_name])
      elsif exists_non_distributed?
        wls_config.destroy('Queue', bean_path.subst(as_non_distributed), self[key_name])
      else
        fail "#{path}: queue doesn't exist."
      end
      nil
    end

    #
    # Because bean_path uses the variable object_path, we need to have it available all the time
    # This code adds it to the hash based on the setting of distributed.
    #
    def to_hash
      hash = super
      hash[:object_type] = distributed_to_path
      hash
    end

    def as_distributed
      to_hash.dup.merge(:object_type => 'UniformDistributedQueues')
    end

    def as_non_distributed
      to_hash.dup.merge(:object_type => 'Queues')
    end

    def exists_distributed?
      wls_config.exists?("#{bean_path.subst(as_distributed)}/#{self[key_name]}")
    end

    def exists_non_distributed?
      wls_config.exists?("#{bean_path.subst(as_non_distributed)}/#{self[key_name]}")
    end

    #
    # Only use elements on the path where this condition is true. The condition is
    # that is has specified serverTemplates
    #
    index_condition do |_name, path, _wls_config|
      %w[Queues UniformDistributedQueues].include?(path.split('/').last)
    end

    ensurable
    parameter :queue_name
    parameter :errordestinationtype
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :distributed
    property :jndiname
    property :subdeployment
    property :balancingpolicy
    property :quota
    property :defaulttargeting
    property :errordestination
    property :expirationloggingpolicy
    property :redeliverylimit
    property :expirationpolicy
    property :redeliverydelay
    property :timetodeliver
    property :deliverymode
    property :timetolive
    property :forwarddelay
    property :templatename
    property :messagelogging
    property :destination_keys
    property :insertionpaused
    property :consumptionpaused
    property :productionpaused
    extraproperties do
      property :override_delivery_mode
      property :override_priority
      property :override_redelivery_delay
      property :override_template_bean
      property :override_time_to_deliver
      property :override_time_to_live
      property :thresholds_bytes_high
      property :thresholds_bytes_low
      property :thresholds_messages_high
      property :thresholds_messages_low
      property :thresholds_template_bean
      property :attach_sender
      property :delivery_expiration_logging_policy
      property :delivery_expiration_policy
      property :delivery_redelivery_limit
      property :delivery_template_bean
      property :incomplete_work_expiration_time
      property :insertion_paused_at_startup
      property :jms_create_destination_identifier
      property :jndi_name
      property :local_jndi_name
      property :log_message_logging_enabled
      property :log_message_logging_format
      property :log_template_bean
      property :maximum_message_size
      property :production_paused_at_startup
      property :reset_delivery_count_on_forward
      property :saf_export_policy
      property :consumption_paused_at_startup
      property :default_targeting_enabled
      property :default_unit_of_order
      property :load_balancing_policy
      property :messaging_performance_preference
      property :notes
      property :sub_deployment_name
      property :template
      property :unit_of_order_routing
      property :unit_of_work_handling_policy
      property :forward_delay
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :queue_name) do
      /(.+):(.+)/
    end

    def distributed_to_path
      case distributed
      when 0, '0' then 'Queues'
      when 1, '1' then 'UniformDistributedQueues'
      else
        fail "#{path}: Invalid value for distributed"
      end
    end
  end
end
